summaryrefslogtreecommitdiffstats
path: root/tests/postbuild
diff options
context:
space:
mode:
authorVille Voutilainen <ville.voutilainen@qt.io>2021-01-18 12:34:58 +0200
committerVille Voutilainen <ville.voutilainen@qt.io>2021-01-18 13:06:53 +0000
commit76cbacd082012cb13f5ed52317eea78e02156776 (patch)
tree30229f3130ea30d46bf463e1908cca82d84c55ca /tests/postbuild
parent0cb86ebe6e412685e9323d311fd301cfcbe734c4 (diff)
Build fixes for GCC 11
Task-number: QTBUG-89977 Change-Id: Ia488d2b36f4b05e5485e56ed7fdb5ee62ead321f Pick-to: master Reviewed-by: Friedemann Kleint <Friedemann.Kleint@qt.io>
Diffstat (limited to 'tests/postbuild')
-rw-r--r--tests/postbuild/guiapplauncher/CMakeLists.txt2
-rw-r--r--tests/postbuild/guiapplauncher/windowmanager.cpp24
-rw-r--r--tests/postbuild/guiapplauncher/windowmanager.h8
3 files changed, 18 insertions, 16 deletions
diff --git a/tests/postbuild/guiapplauncher/CMakeLists.txt b/tests/postbuild/guiapplauncher/CMakeLists.txt
index 86e463b3..dcc1141f 100644
--- a/tests/postbuild/guiapplauncher/CMakeLists.txt
+++ b/tests/postbuild/guiapplauncher/CMakeLists.txt
@@ -28,4 +28,6 @@ qt_internal_extend_target(tst_guiapplauncher CONDITION WIN32
qt_internal_extend_target(tst_guiapplauncher CONDITION QT_FEATURE_xlib # special case
DEFINES
Q_WS_X11
+ PUBLIC_LIBRARIES
+ X11
)
diff --git a/tests/postbuild/guiapplauncher/windowmanager.h b/tests/postbuild/guiapplauncher/windowmanager.h
index e61ea4ac..72a31f3d 100644
--- a/tests/postbuild/guiapplauncher/windowmanager.h
+++ b/tests/postbuild/guiapplauncher/windowmanager.h
@@ -48,16 +48,16 @@ public:
bool isDisplayOpen() const;
// Count: Number of toplevels, 1 for normal apps, 2 for apps with a splash screen
- QString waitForTopLevelWindow(unsigned count, Q_PID pid, int timeOutMS, QString *errorMessage);
- bool sendCloseEvent(const QString &winId, Q_PID pid, QString *errorMessage);
+ QString waitForTopLevelWindow(unsigned count, qint64 pid, int timeOutMS, QString *errorMessage);
+ bool sendCloseEvent(const QString &winId, qint64 pid, QString *errorMessage);
protected:
WindowManager();
virtual bool openDisplayImpl(QString *errorMessage);
virtual bool isDisplayOpenImpl() const;
- virtual QString waitForTopLevelWindowImpl(unsigned count, Q_PID pid, int timeOutMS, QString *errorMessage);
- virtual bool sendCloseEventImpl(const QString &winId, Q_PID pid, QString *errorMessage);
+ virtual QString waitForTopLevelWindowImpl(unsigned count, qint64 pid, int timeOutMS, QString *errorMessage);
+ virtual bool sendCloseEventImpl(const QString &winId, qint64 pid, QString *errorMessage);
};
#endif // WINDOWMANAGER_H
diff --git a/tests/postbuild/guiapplauncher/windowmanager.cpp b/tests/postbuild/guiapplauncher/windowmanager.cpp
index 2cc82cc7..f628efb6 100644
--- a/tests/postbuild/guiapplauncher/windowmanager.cpp
+++ b/tests/postbuild/guiapplauncher/windowmanager.cpp
@@ -185,9 +185,9 @@ public:
protected:
bool isDisplayOpenImpl() const override;
bool openDisplayImpl(QString *errorMessage) override;
- QString waitForTopLevelWindowImpl(unsigned count, Q_PID, int timeOutMS,
+ QString waitForTopLevelWindowImpl(unsigned count, qint64, int timeOutMS,
QString *errorMessage) override;
- bool sendCloseEventImpl(const QString &winId, Q_PID pid,
+ bool sendCloseEventImpl(const QString &winId, qint64 pid,
QString *errorMessage) override;
private:
@@ -232,7 +232,7 @@ bool X11_WindowManager::openDisplayImpl(QString *errorMessage)
return true;
}
-QString X11_WindowManager::waitForTopLevelWindowImpl(unsigned count, Q_PID, int timeOutMS, QString *errorMessage)
+QString X11_WindowManager::waitForTopLevelWindowImpl(unsigned count, qint64, int timeOutMS, QString *errorMessage)
{
const Window w = waitForTopLevelMapped(m_display, count, timeOutMS, errorMessage);
if (w == 0)
@@ -240,7 +240,7 @@ QString X11_WindowManager::waitForTopLevelWindowImpl(unsigned count, Q_PID, int
return QLatin1String("0x") + QString::number(w, 16);
}
- bool X11_WindowManager::sendCloseEventImpl(const QString &winId, Q_PID, QString *errorMessage)
+ bool X11_WindowManager::sendCloseEventImpl(const QString &winId, qint64, QString *errorMessage)
{
// Get win id
bool ok;
@@ -310,9 +310,9 @@ QString X11_WindowManager::waitForTopLevelWindowImpl(unsigned count, Q_PID, int
protected:
bool isDisplayOpenImpl() const override;
bool openDisplayImpl(QString *errorMessage) override;
- QString waitForTopLevelWindowImpl(unsigned count, Q_PID, int timeOutMS,
+ QString waitForTopLevelWindowImpl(unsigned count, qint64, int timeOutMS,
QString *errorMessage) override;
- virtual bool sendCloseEventImpl(const QString &winId, Q_PID pid,
+ virtual bool sendCloseEventImpl(const QString &winId, qint64 pid,
QString *errorMessage) override;
private:
@@ -367,7 +367,7 @@ static BOOL CALLBACK findProcessWindowEnumWindowProc(HWND hwnd, LPARAM lParam)
return TRUE;
}
-QString Win_WindowManager::waitForTopLevelWindowImpl(unsigned /* count */, Q_PID pid, int timeOutMS, QString *errorMessage)
+QString Win_WindowManager::waitForTopLevelWindowImpl(unsigned /* count */, qint64 pid, int timeOutMS, QString *errorMessage)
{
QElapsedTimer elapsed;
elapsed.start();
@@ -392,7 +392,7 @@ QString Win_WindowManager::waitForTopLevelWindowImpl(unsigned /* count */, Q_PID
return QString();
}
-bool Win_WindowManager::sendCloseEventImpl(const QString &winId, Q_PID, QString *errorMessage)
+bool Win_WindowManager::sendCloseEventImpl(const QString &winId, qint64, QString *errorMessage)
{
// Convert window back.
quintptr winIdIntPtr;
@@ -449,7 +449,7 @@ bool WindowManager::isDisplayOpen() const
-QString WindowManager::waitForTopLevelWindow(unsigned count, Q_PID pid, int timeOutMS, QString *errorMessage)
+QString WindowManager::waitForTopLevelWindow(unsigned count, qint64 pid, int timeOutMS, QString *errorMessage)
{
if (!isDisplayOpen()) {
*errorMessage = msgNoDisplayOpen();
@@ -458,7 +458,7 @@ QString WindowManager::waitForTopLevelWindow(unsigned count, Q_PID pid, int time
return waitForTopLevelWindowImpl(count, pid, timeOutMS, errorMessage);
}
-bool WindowManager::sendCloseEvent(const QString &winId, Q_PID pid, QString *errorMessage)
+bool WindowManager::sendCloseEvent(const QString &winId, qint64 pid, QString *errorMessage)
{
if (!isDisplayOpen()) {
*errorMessage = msgNoDisplayOpen();
@@ -479,13 +479,13 @@ bool WindowManager::isDisplayOpenImpl() const
return false;
}
-QString WindowManager::waitForTopLevelWindowImpl(unsigned, Q_PID, int, QString *errorMessage)
+QString WindowManager::waitForTopLevelWindowImpl(unsigned, qint64, int, QString *errorMessage)
{
*errorMessage = QLatin1String("Not implemented.");
return QString();
}
-bool WindowManager::sendCloseEventImpl(const QString &, Q_PID, QString *errorMessage)
+bool WindowManager::sendCloseEventImpl(const QString &, qint64, QString *errorMessage)
{
*errorMessage = QLatin1String("Not implemented.");
return false;